@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use Carp;
 
-our $VERSION = 'v0.4.1'; # VERSION
+our $VERSION = 'v0.4.2'; # VERSION
 
 use Moose;
 with qw(
@@ -110,7 +110,7 @@ Business::CyberSource::Request::Authorization - CyberSource Authorization Reques
 
 =head1 VERSION
 
-version v0.4.1
+version v0.4.2
 
 =head1 SYNOPSIS
 
@@ -276,6 +276,12 @@ Type: MooseX::Types::CreditCard::CardSecurityCode
 
 Additional documentation: Card Verification Numbers
 
+=head2 phone_number
+
+Reader: phone_number
+
+Type: MooseX::Types::Varchar::Varchar[20]
+
 =head2 total
 
 Reader: total
@@ -518,6 +524,12 @@ Reader: client_version
 
 Type: Str
 
+=head2 items
+
+Reader: items
+
+Type: ArrayRef[MooseX::Types::CyberSource::Item]
+
 =head2 first_name
 
 Reader: first_name
@@ -528,12 +540,6 @@ This attribute is required.
 
 Additional documentation: Customer's first name.The value should be the same as the one that is on the card.
 
-=head2 items
-
-Reader: items
-
-Type: ArrayRef[MooseX::Types::CyberSource::Item]
-
 =head1 METHODS
 
 =head2 new
